==> AuthNetAim-1.2.6.tar.gz: AuthNetAim/function.prefs_tab.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: AuthNetSim (c) 2009 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module for CMS Made Simple to provide the ability to process
#  Payments made using the E-commerce suite through the AuthNet payment
#  gateway.
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

$smarty->assign('formstart',$this->CGCreateFormStart($id,'admin_setprefs'));
$smarty->assign('formend',$this->CreateFormEnd());

$smarty->assign('testmode',$this->GetPreference('testmode'));
$smarty->assign('usetesturl',$this->GetPreference('usetesturl'));
$smarty->assign('loginid',$this->GetPreference('loginid'));
$smarty->assign('transactionkey',$this->GetPreference('transactionkey'));

echo $this->ProcessTemplate('prefs_tab.tpl');
#
# EOF
#
?>

==> AuthNetAim-1.3.tar.gz: AuthNetAim/function.prefs_tab.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: AuthNetSim (c) 2009 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module for CMS Made Simple to provide the ability to process
#  Payments made using the E-commerce suite through the AuthNet payment
#  gateway.
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

$contentops = $gCms->GetContentOperations();
$silent_post_url = $this->create_url($id,'silent_post',$contentops->GetDefaultContent(),array(),false,false,$this->GetName().'/silent_post');
$smarty->assign('silent_post_url',$silent_post_url);

$smarty->assign('formstart',$this->CGCreateFormStart($id,'admin_setprefs'));
$smarty->assign('formend',$this->CreateFormEnd());

$smarty->assign('allow_subscriptions',$this->GetPreference('allow_subscriptions'));
$smarty->assign('testmode',$this->GetPreference('testmode'));
$smarty->assign('usetesturl',$this->GetPreference('usetesturl'));
$smarty->assign('loginid',$this->GetPreference('loginid'));
$smarty->assign('transactionkey',$this->GetPreference('transactionkey'));

echo $this->ProcessTemplate('prefs_tab.tpl');
#
# EOF
#
?>
